@@ -282,13 +282,20 @@ class Filters:
         "config:overrides"
     )
 
-    #: Declare uniqaue configuration settings that must be saved in the user ``config.yml`` file. This is where
+    #: Declare unique configuration settings that must be saved in the user ``config.yml`` file. This is where
     #: you should declare passwords and randomly-generated values that are different from one environment to the next.
     #:
     #: :parameter list[tuple[str, ...]] items: list of (name, value) new settings. All
     #:   names must be prefixed with the plugin name in all-caps.
     CONFIG_UNIQUE: Filter[list[tuple[str, Any]], []] = filters.get("config:unique")
 
+    #: Use this filter to modify the ``docker build`` command. For instance, to replace
+    #: the ``build`` subcommand by ``buildx build``.
+    #:
+    #: :parameter list[str] command: the full build command, including options and
+    #:   arguments. Note that these arguments do not include the leading ``docker`` command.
+    DOCKER_BUILD_COMMAND: Filter[list[str], []] = filters.get("docker:build:command")
+
     #: List of patches that should be inserted in a given location of the templates. The
     #: filter name must be formatted with the patch name.
     #: This filter is not so convenient and plugin developers will probably
