@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 # The Tutor plugin system is licensed under the terms of the Apache 2.0 license.
 __license__ = "Apache 2.0"
 
@@ -18,6 +20,7 @@ ConfigValue: TypeAlias = t.Union[
     t.Dict[t.Any, t.Any],
 ]
 
+#: Type alias for the user configuration.
 Config: TypeAlias = t.Dict[str, ConfigValue]
 
 
@@ -38,14 +41,14 @@ T = t.TypeVar("T")
 
 
 def get_typed(
-    config: t.Dict[str, t.Any],
+    config: dict[str, t.Any],
     key: str,
-    expected_type: t.Type[T],
+    expected_type: type[T],
     default: t.Optional[T] = None,
 ) -> T:
     value = config.get(key, default)
     if not isinstance(value, expected_type):
         raise exceptions.TutorError(
-            "Invalid config entry: expected {expected_type.__name__}, got {value.__class__} for key '{key}'"
+            f"Invalid config entry: expected {expected_type.__name__}, got {value.__class__} for key '{key}'"
         )
     return value
